@@ -6,12 +6,6 @@ use base 'Perl::Dist::Strawberry::Step';
 
 use File::Spec::Functions qw(catfile);
 
-sub new {
-  my $class = shift;
-  my $self = $class->SUPER::new(@_);
-  return $self;
-}
-
 sub run {
   my $self = shift;
     
